@@ -154,6 +154,19 @@ static const char* acceptable_fields[] = {
     "SystemImageInfo",
     /* We always want to know why apport thought it shouldn't be reported. */
     "UnreportableReason",
+    /* Package Install Failure Information */
+    /* update-manager */
+    "DpkgHistoryLog.txt",
+    "DpkgTerminalLog.txt",
+    "AptDaemon",
+    "HWEunsupported",
+    /* aptdaemon */
+    "AptConfig",
+    "SourcesList",
+    "AptHistoryLog",
+    "AptTermLog",
+    "DpkgLog",
+    "SysLog",
 
     NULL,
 };
@@ -712,9 +725,10 @@ process_existing_files (const char* report_dir)
             g_free (crash_file);
             continue;
         } else if (online_state && parse_and_upload_report (crash_file)) {
-            if (!mark_handled (crash_file))
+            if (!mark_handled (crash_file)) {
                 log_msg ("Unable to mark report as seen (%s) removing it.\n", crash_file);
                 g_unlink (crash_file);
+            }
         }
 
         g_free (upload_file);
